PatchbayArtifactService class final

Explicitly injected log/blob command module shared by core and Flutter.

Constructors

PatchbayArtifactService({required PatchbayMemoryBlobStore blobs, required PatchbayGateEvaluator gates, PatchbayLogSource? logs, Set<String> gateIds = const <String>{}, int maxQueryRecords = 500, int maxExportRecords = 2000, int maxBatchBytes = 256 * 1024, Duration maxTailTimeout = const Duration(seconds: 30), Duration queryTimeout = const Duration(seconds: 2)})

Properties

blobs PatchbayMemoryBlobStore
final
descriptors List<PatchbayCommandDescriptor>
no setter
hashCode int
The hash code for this object.
no setterinherited
logsEnabled bool
no setter
maxBatchBytes int
final
maxExportRecords int
final
maxQueryRecords int
final
maxTailTimeout Duration
final
queryTimeout Duration
final
registry PatchbayCommandRegistry
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
handles(String command) bool
invoke(String command, Map<String, Object?> arguments, String requestId) Future<Map<String, Object?>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited