PatchbayBlobMetadataWire class final
Strict wire representation of PatchbayBlobMetadataWire.
Constructors
-
PatchbayBlobMetadataWire({required String blobId, required PatchbayFactSourceWire source, required PatchbayBlobSourceWire kind, required String contentType, required int length, required String sha256, required String createdAt, required String expiresAt, required String? filename, required Map<
String, Object?> properties}) -
Creates a fully validated wire value.
const
-
PatchbayBlobMetadataWire.fromJson(Map<
String, Object?> json, {String path = r'$'}) -
Decodes a strict JSON object at
path.factory
Properties
- blobId → String
-
Value of the
blobIdwire field.final - contentType → String
-
Value of the
contentTypewire field.final - createdAt → String
-
Value of the
createdAtwire field.final - expiresAt → String
-
Value of the
expiresAtwire field.final - filename → String?
-
Value of the
filenamewire field.final - hashCode → int
-
The hash code for this object.
no setterinherited
- kind → PatchbayBlobSourceWire
-
Value of the
kindwire field.final - length → int
-
Value of the
lengthwire field.final -
properties
→ Map<
String, Object?> -
Value of the
propertieswire field.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sha256 → String
-
Value of the
sha256wire field.final - source → PatchbayFactSourceWire
-
Value of the
sourcewire field.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this value as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited