PatchbayLogRecordWire class final

Strict wire representation of PatchbayLogRecordWire.

Constructors

PatchbayLogRecordWire({required String cursor, required String at, required PatchbayLogLevelWire level, required String category, required String message, required Map<String, Object?> fields, required PatchbayLogRedactionWire redaction, required PatchbayFactSourceWire source})
Creates a fully validated wire value.
const
PatchbayLogRecordWire.fromJson(Map<String, Object?> json, {String path = r'$'})
Decodes a strict JSON object at path.
factory

Properties

at String
Value of the at wire field.
final
category String
Value of the category wire field.
final
cursor String
Value of the cursor wire field.
final
fields Map<String, Object?>
Value of the fields wire field.
final
hashCode int
The hash code for this object.
no setterinherited
level PatchbayLogLevelWire
Value of the level wire field.
final
message String
Value of the message wire field.
final
redaction PatchbayLogRedactionWire
Value of the redaction wire field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source PatchbayFactSourceWire
Value of the source wire field.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this value as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited