Consumer injection seam for already-redacted structured records.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
query(
PatchbayLogQuery query, PatchbayCancellationSignal cancellation) → Future< PatchbayLogPage> -
tail(
PatchbayLogQuery query, PatchbayCancellationSignal cancellation) → Future< PatchbayLogPage> - Waits for records strictly after PatchbayLogQuery.cursor. The service still owns and enforces the outer timeout and cancels this signal when it expires or is disposed.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited