executionDetails property
Host-only projection of confirmed execution facts, or null when it does not apply. See PatchbayAuditExecutionDetails. PB-050-26 / DG-060-04.
Implementation
final PatchbayAuditExecutionDetails? executionDetails;
Host-only projection of confirmed execution facts, or null when it does not apply. See PatchbayAuditExecutionDetails. PB-050-26 / DG-060-04.
final PatchbayAuditExecutionDetails? executionDetails;