PatchbayInvocation class final
Admission envelope. It deliberately does not claim domain execution.
Constructors
-
PatchbayInvocation.accepted({required String requestId, Map<
String, Object?> payload = const <String, Object?>{}, String? notice, String? jobId}) -
factory
- PatchbayInvocation.rejected({required String requestId, required PatchbayRejection rejection})
-
factory
Properties
- admission → PatchbayAdmission
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- jobId → String?
-
final
- notice → String?
-
final
-
payload
→ Map<
String, Object?> -
final
- rejection → PatchbayRejection?
-
final
- requestId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- schemaVersion → const int