PatchbayInvocationCancellationResult class final

Immutable control-plane answer. It never includes the owner token.

Constructors

PatchbayInvocationCancellationResult({required String command, required String requestId, required PatchbayInvocationCancellationOutcome outcome, PatchbayInvocationCancellationReason? reason, PatchbayInvocationConfirmationState? confirmation})
const

Properties

command String
final
confirmation PatchbayInvocationConfirmationState?
final
hashCode int
The hash code for this object.
no setterinherited
outcome PatchbayInvocationCancellationOutcome
final
reason PatchbayInvocationCancellationReason?
final
requestId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited