PatchbayResponseValidationIssue class final
One value-free validation issue safe to return to an untrusted caller.
Constructors
- PatchbayResponseValidationIssue({required String field, required String reason, String? expected})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited