PatchbayBlobMetadataRequestWire class final

Strict wire representation of PatchbayBlobMetadataRequestWire.

Constructors

PatchbayBlobMetadataRequestWire({required String blobId})
Creates a fully validated wire value.
const
PatchbayBlobMetadataRequestWire.fromJson(Map<String, Object?> json, {String path = r'$'})
Decodes a strict JSON object at path.
factory

Properties

blobId String
Value of the blobId wire field.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this value as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited