PatchbayBlobReadRequestWire class final

Strict wire representation of PatchbayBlobReadRequestWire.

Constructors

PatchbayBlobReadRequestWire({required String blobId, required int offset, required int? limit})
Creates a fully validated wire value.
const
PatchbayBlobReadRequestWire.fromJson(Map<String, Object?> json, {String path = r'$'})
Decodes a strict JSON object at path.
factory

Properties

blobId String
Value of the blobId wire field.
final
hashCode int
The hash code for this object.
no setterinherited
limit int?
Value of the limit wire field.
final
offset int
Value of the offset wire field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this value as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited