PatchbayCaptureRequestWire class final
Strict wire representation of PatchbayCaptureRequestWire.
Constructors
- PatchbayCaptureRequestWire({required String? targetId, required int? generation, required num? pixelRatio, required int? timeoutMs, required int? afterFrames})
-
Creates a fully validated wire value.
const
-
PatchbayCaptureRequestWire.fromJson(Map<
String, Object?> json, {String path = r'$'}) -
Decodes a strict JSON object at
path.factory
Properties
- afterFrames → int?
-
Value of the
afterFrameswire field.final - generation → int?
-
Value of the
generationwire field.final - hashCode → int
-
The hash code for this object.
no setterinherited
- pixelRatio → num?
-
Value of the
pixelRatiowire field.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetId → String?
-
Value of the
targetIdwire field.final - timeoutMs → int?
-
Value of the
timeoutMswire field.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this value as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited