PatchbayCatalogDigestWire class final

Strict wire representation of PatchbayCatalogDigestWire.

Constructors

PatchbayCatalogDigestWire({required String algorithm, required List<String> covers, required String value})
Creates a fully validated wire value.
const
PatchbayCatalogDigestWire.fromJson(Map<String, Object?> json, {String path = r'$'})
Decodes a strict JSON object at path.
factory

Properties

algorithm String
Value of the algorithm wire field.
final
covers List<String>
Value of the covers wire field.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
Value of the value wire field.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this value as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited