PatchbayCommandDescriptorWire class final
Strict wire representation of PatchbayCommandDescriptorWire.
Constructors
-
PatchbayCommandDescriptorWire({required String name, required String summary, required PatchbayPlaneWire plane, required PatchbayCommandModeWire mode, required PatchbaySideEffectWire sideEffect, required List<
PatchbayFactSourceWire> factSources, required List<String> gates, required List<PatchbayParameterDescriptorWire> parameters}) -
Creates a fully validated wire value.
const
-
PatchbayCommandDescriptorWire.fromJson(Map<
String, Object?> json, {String path = r'$'}) -
Decodes a strict JSON object at
path.factory
Properties
-
factSources
→ List<
PatchbayFactSourceWire> -
Value of the
factSourceswire field.final -
gates
→ List<
String> -
Value of the
gateswire field.final - hashCode → int
-
The hash code for this object.
no setterinherited
- mode → PatchbayCommandModeWire
-
Value of the
modewire field.final - name → String
-
Value of the
namewire field.final -
parameters
→ List<
PatchbayParameterDescriptorWire> -
Value of the
parameterswire field.final - plane → PatchbayPlaneWire
-
Value of the
planewire field.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sideEffect → PatchbaySideEffectWire
-
Value of the
sideEffectwire field.final - summary → String
-
Value of the
summarywire field.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this value as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited