PatchbayIdentityWire class final

Strict wire representation of PatchbayIdentityWire.

Constructors

PatchbayIdentityWire({required int schemaVersion, required String serverVersion, required List<String> features, required String applicationId, required String appInstanceId, required String? isolateId})
Creates a fully validated wire value.
const
PatchbayIdentityWire.fromJson(Map<String, Object?> json, {String path = r'$'})
Decodes a strict JSON object at path.
factory

Properties

appInstanceId String
Value of the appInstanceId wire field.
final
applicationId String
Value of the applicationId wire field.
final
features List<String>
Value of the features wire field.
final
hashCode int
The hash code for this object.
no setterinherited
isolateId String?
Value of the isolateId wire field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemaVersion int
Value of the schemaVersion wire field.
final
serverVersion String
Value of the serverVersion wire field.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this value as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited