PatchbayInspectStateWire class final

Strict wire representation of PatchbayInspectStateWire.

Constructors

PatchbayInspectStateWire({required String outcome, required PatchbayFactSourceWire source, required bool selectMode, required bool selectionOnTap, required bool managed, required bool? previousSelectMode, required bool? restoresTo, required int? leaseMs, required int? leaseRemainingMs, required PatchbayInspectReleaseWire? lastRelease})
Creates a fully validated wire value.
const
PatchbayInspectStateWire.fromJson(Map<String, Object?> json, {String path = r'$'})
Decodes a strict JSON object at path.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
lastRelease PatchbayInspectReleaseWire?
Value of the lastRelease wire field.
final
leaseMs int?
Value of the leaseMs wire field.
final
leaseRemainingMs int?
Value of the leaseRemainingMs wire field.
final
managed bool
Value of the managed wire field.
final
outcome String
Value of the outcome wire field.
final
previousSelectMode bool?
Value of the previousSelectMode wire field.
final
restoresTo bool?
Value of the restoresTo wire field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectionOnTap bool
Value of the selectionOnTap wire field.
final
selectMode bool
Value of the selectMode wire field.
final
source PatchbayFactSourceWire
Value of the source wire field.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this value as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited