PatchbayInvocationWire class final

Strict wire representation of PatchbayInvocationWire.

Constructors

PatchbayInvocationWire({required int schemaVersion, required String requestId, required PatchbayAdmissionWire admission, required Map<String, Object?> payload, required String? notice, required String? jobId, required PatchbayRejectionWire? rejection})
Creates a fully validated wire value.
const
PatchbayInvocationWire.fromJson(Map<String, Object?> json, {String path = r'$'})
Decodes a strict JSON object at path.
factory

Properties

admission PatchbayAdmissionWire
Value of the admission wire field.
final
hashCode int
The hash code for this object.
no setterinherited
jobId String?
Value of the jobId wire field.
final
notice String?
Value of the notice wire field.
final
payload Map<String, Object?>
Value of the payload wire field.
final
rejection PatchbayRejectionWire?
Value of the rejection wire field.
final
requestId String
Value of the requestId wire field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemaVersion int
Value of the schemaVersion wire field.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this value as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited