PatchbayKeepAwakeRequestWire class final

Strict wire representation of PatchbayKeepAwakeRequestWire.

Constructors

PatchbayKeepAwakeRequestWire({required bool enabled, required int? leaseMs})
Creates a fully validated wire value.
const
PatchbayKeepAwakeRequestWire.fromJson(Map<String, Object?> json, {String path = r'$'})
Decodes a strict JSON object at path.
factory

Properties

enabled bool
Value of the enabled wire field.
final
hashCode int
The hash code for this object.
no setterinherited
leaseMs int?
Value of the leaseMs wire field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this value as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited