PatchbayKeepAwakeStateWire class final
Strict wire representation of PatchbayKeepAwakeStateWire.
Constructors
- PatchbayKeepAwakeStateWire({required String outcome, required PatchbayFactSourceWire source, required bool wired, required bool enabled, required int? leaseMs, required int? leaseRemainingMs, required PatchbayKeepAwakeReleaseWire? lastRelease, required String? lastReleaseFailure})
-
Creates a fully validated wire value.
const
-
PatchbayKeepAwakeStateWire.fromJson(Map<
String, Object?> json, {String path = r'$'}) -
Decodes a strict JSON object at
path.factory
Properties
- enabled → bool
-
Value of the
enabledwire field.final - hashCode → int
-
The hash code for this object.
no setterinherited
- lastRelease → PatchbayKeepAwakeReleaseWire?
-
Value of the
lastReleasewire field.final - lastReleaseFailure → String?
-
Value of the
lastReleaseFailurewire field.final - leaseMs → int?
-
Value of the
leaseMswire field.final - leaseRemainingMs → int?
-
Value of the
leaseRemainingMswire field.final - outcome → String
-
Value of the
outcomewire field.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → PatchbayFactSourceWire
-
Value of the
sourcewire field.final - wired → bool
-
Value of the
wiredwire field.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this value as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited