PatchbayLogBatchWire class final

Strict wire representation of PatchbayLogBatchWire.

Constructors

PatchbayLogBatchWire({required PatchbayLogBatchOutcomeWire outcome, required PatchbayFactSourceWire source, required List<PatchbayLogRecordWire> records, required String? nextCursor, required String? currentCursor, required bool truncated, required PatchbayLogTruncationWire? truncation, required int elapsedMs})
Creates a fully validated wire value.
const
PatchbayLogBatchWire.fromJson(Map<String, Object?> json, {String path = r'$'})
Decodes a strict JSON object at path.
factory

Properties

currentCursor String?
Value of the currentCursor wire field.
final
elapsedMs int
Value of the elapsedMs wire field.
final
hashCode int
The hash code for this object.
no setterinherited
nextCursor String?
Value of the nextCursor wire field.
final
outcome PatchbayLogBatchOutcomeWire
Value of the outcome wire field.
final
records List<PatchbayLogRecordWire>
Value of the records wire field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source PatchbayFactSourceWire
Value of the source wire field.
final
truncated bool
Value of the truncated wire field.
final
truncation PatchbayLogTruncationWire?
Value of the truncation wire field.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this value as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited