PatchbayLogExportResultWire class final

Strict wire representation of PatchbayLogExportResultWire.

Constructors

PatchbayLogExportResultWire({required PatchbayFactSourceWire source, required PatchbayBlobMetadataWire blob, required int recordCount, required bool truncated, required PatchbayLogTruncationWire? truncation})
Creates a fully validated wire value.
const
PatchbayLogExportResultWire.fromJson(Map<String, Object?> json, {String path = r'$'})
Decodes a strict JSON object at path.
factory

Properties

blob PatchbayBlobMetadataWire
Value of the blob wire field.
final
hashCode int
The hash code for this object.
no setterinherited
recordCount int
Value of the recordCount wire field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source PatchbayFactSourceWire
Value of the source wire field.
final
truncated bool
Value of the truncated wire field.
final
truncation PatchbayLogTruncationWire?
Value of the truncation wire field.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this value as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited