PatchbayNavigationCatalogWire class final

Strict wire representation of PatchbayNavigationCatalogWire.

Constructors

PatchbayNavigationCatalogWire({required String outcome, required PatchbayFactSourceWire source, required int navigationRevision, required List<PatchbayDestinationDescriptorWire> destinations})
Creates a fully validated wire value.
const
PatchbayNavigationCatalogWire.fromJson(Map<String, Object?> json, {String path = r'$'})
Decodes a strict JSON object at path.
factory

Properties

destinations List<PatchbayDestinationDescriptorWire>
Value of the destinations wire field.
final
hashCode int
The hash code for this object.
no setterinherited
Value of the navigationRevision wire field.
final
outcome String
Value of the outcome wire field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source PatchbayFactSourceWire
Value of the source wire field.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this value as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited