PatchbayNavigationCurrentWire class final

Strict wire representation of PatchbayNavigationCurrentWire.

Constructors

PatchbayNavigationCurrentWire({required String outcome, required PatchbayFactSourceWire source, required int navigationRevision, required String? destinationId})
Creates a fully validated wire value.
const
PatchbayNavigationCurrentWire.fromJson(Map<String, Object?> json, {String path = r'$'})
Decodes a strict JSON object at path.
factory

Properties

destinationId String?
Value of the destinationId wire field.
final
hashCode int
The hash code for this object.
no setterinherited
Value of the navigationRevision wire field.
final
outcome String
Value of the outcome wire field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source PatchbayFactSourceWire
Value of the source wire field.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this value as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited