PatchbayNavigationResultWire class final
Strict wire representation of PatchbayNavigationResultWire.
Constructors
-
Creates a fully validated wire value.
const
-
Decodes a strict JSON object at
path.factory
Properties
-
Value of the
afterNavigationRevisionwire field.final -
Value of the
beforeNavigationRevisionwire field.final - destinationId → String
-
Value of the
destinationIdwire field.final - frameRevision → int
-
Value of the
frameRevisionwire field.final - hashCode → int
-
The hash code for this object.
no setterinherited
- operation → PatchbayNavigationOperationWire
-
Value of the
operationwire field.final - outcome → String
-
Value of the
outcomewire field.final - requestedDestinationId → String?
-
Value of the
requestedDestinationIdwire field.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → PatchbayFactSourceWire
-
Value of the
sourcewire field.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this value as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited