PatchbayParameterTypeWire enum
Strict wire representation of PatchbayParameterTypeWire.
Values
- string → const PatchbayParameterTypeWire
-
The
stringwire value. - integer → const PatchbayParameterTypeWire
-
The
integerwire value. - number → const PatchbayParameterTypeWire
-
The
numberwire value. - boolean → const PatchbayParameterTypeWire
-
The
booleanwire value. - enumeration → const PatchbayParameterTypeWire
-
The
enumerationwire value. - json → const PatchbayParameterTypeWire
-
The
jsonwire value.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String - Encodes this value using its stable wire name.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Object? value, {String path = r'$'}) → PatchbayParameterTypeWire -
Decodes a value at
path, rejecting unknown values.
Constants
-
values
→ const List<
PatchbayParameterTypeWire> - A constant List of the values in this enum, in order of their declaration.