PatchbayPermissionCapabilities class final
Constructors
-
PatchbayPermissionCapabilities({required String platform, required String driver, required String driverVersion, required Map<
String, PatchbayPermissionCapability> permissions}) -
const
-
PatchbayPermissionCapabilities.fromJson(Map<
String, Object?> json) -
factory
Properties
- driver → String
-
final
- driverVersion → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
permissions
→ Map<
String, PatchbayPermissionCapability> -
final
- platform → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited