PatchbayPermissionStatus class final
Constructors
-
PatchbayPermissionStatus({required String permission, required String platformPermission, required PatchbayPermissionState state, required String platformState, required PatchbayPermissionFactSource factSource, required String driver, required String driverVersion, required Set<
PatchbayPermissionAction> supportedActions, required bool requiresRestart, required bool requiresSettings, required bool systemUiExpected, String? notice}) -
const
-
PatchbayPermissionStatus.fromJson(Map<
String, Object?> json) -
factory
Properties
- driver → String
-
final
- driverVersion → String
-
final
- factSource → PatchbayPermissionFactSource
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- notice → String?
-
final
- permission → String
-
final
- platformPermission → String
-
final
- platformState → String
-
final
- requiresRestart → bool
-
final
- requiresSettings → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → PatchbayPermissionState
-
final
-
supportedActions
→ Set<
PatchbayPermissionAction> -
final
- systemUiExpected → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited