PatchbayRejectionWire class final
Strict wire representation of PatchbayRejectionWire.
Constructors
Properties
- code → String
-
Value of the
codewire field.final -
details
→ Map<
String, Object?> -
Value of the
detailswire field.final - hashCode → int
-
The hash code for this object.
no setterinherited
- notice → String?
-
Value of the
noticewire field.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this value as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited