PatchbayRevealContainerWire class final

Strict wire representation of PatchbayRevealContainerWire.

Constructors

PatchbayRevealContainerWire({required int nodeId, required int generation, required int steps, required PatchbayRevealDirectionWire direction, required int extentGrowthSteps})
Creates a fully validated wire value.
const
PatchbayRevealContainerWire.fromJson(Map<String, Object?> json, {String path = r'$'})
Decodes a strict JSON object at path.
factory

Properties

direction PatchbayRevealDirectionWire
Value of the direction wire field.
final
extentGrowthSteps int
Value of the extentGrowthSteps wire field.
final
generation int
Value of the generation wire field.
final
hashCode int
The hash code for this object.
no setterinherited
nodeId int
Value of the nodeId wire field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
steps int
Value of the steps wire field.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this value as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited