PatchbaySemanticsNodeWire class final

Strict wire representation of PatchbaySemanticsNodeWire.

Constructors

PatchbaySemanticsNodeWire({required int nodeId, required int generation, required int? parentNodeId, required int depth, required String identifier, required String label, required String? value, required bool? valueRedacted, required String? hint, required String? tooltip, required List<String> flags, required List<String> actions, required bool invisible, required bool userActionsBlocked, required PatchbaySemanticsRectWire rect, required String rectCoordinateSpace, required List<num>? transformToParent, required num? scrollPosition, required num? scrollExtentMin, required num? scrollExtentMax, required int? platformViewId, required List<int> children})
Creates a fully validated wire value.
const
PatchbaySemanticsNodeWire.fromJson(Map<String, Object?> json, {String path = r'$'})
Decodes a strict JSON object at path.
factory

Properties

actions List<String>
Value of the actions wire field.
final
children List<int>
Value of the children wire field.
final
depth int
Value of the depth wire field.
final
flags List<String>
Value of the flags wire field.
final
generation int
Value of the generation wire field.
final
hashCode int
The hash code for this object.
no setterinherited
hint String?
Value of the hint wire field.
final
identifier String
Value of the identifier wire field.
final
invisible bool
Value of the invisible wire field.
final
label String
Value of the label wire field.
final
nodeId int
Value of the nodeId wire field.
final
parentNodeId int?
Value of the parentNodeId wire field.
final
platformViewId int?
Value of the platformViewId wire field.
final
rect PatchbaySemanticsRectWire
Value of the rect wire field.
final
rectCoordinateSpace String
Value of the rectCoordinateSpace wire field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollExtentMax num?
Value of the scrollExtentMax wire field.
final
scrollExtentMin num?
Value of the scrollExtentMin wire field.
final
scrollPosition num?
Value of the scrollPosition wire field.
final
tooltip String?
Value of the tooltip wire field.
final
transformToParent List<num>?
Value of the transformToParent wire field.
final
userActionsBlocked bool
Value of the userActionsBlocked wire field.
final
value String?
Value of the value wire field.
final
valueRedacted bool?
Value of the valueRedacted wire field.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this value as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited