PatchbaySemanticsRectWire class final

Strict wire representation of PatchbaySemanticsRectWire.

Constructors

PatchbaySemanticsRectWire({required num left, required num top, required num width, required num height})
Creates a fully validated wire value.
const
PatchbaySemanticsRectWire.fromJson(Map<String, Object?> json, {String path = r'$'})
Decodes a strict JSON object at path.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
height num
Value of the height wire field.
final
left num
Value of the left wire field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top num
Value of the top wire field.
final
width num
Value of the width wire field.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this value as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited