PatchbaySemanticsSnapshotWire class final
Strict wire representation of PatchbaySemanticsSnapshotWire.
Constructors
-
PatchbaySemanticsSnapshotWire({required String outcome, required PatchbayFactSourceWire source, required int treeRevision, required int rootNodeId, required bool truncated, required int nodeCount, required List<
PatchbaySemanticsNodeWire> nodes}) -
Creates a fully validated wire value.
const
-
PatchbaySemanticsSnapshotWire.fromJson(Map<
String, Object?> json, {String path = r'$'}) -
Decodes a strict JSON object at
path.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nodeCount → int
-
Value of the
nodeCountwire field.final -
nodes
→ List<
PatchbaySemanticsNodeWire> -
Value of the
nodeswire field.final - outcome → String
-
Value of the
outcomewire field.final - rootNodeId → int
-
Value of the
rootNodeIdwire field.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → PatchbayFactSourceWire
-
Value of the
sourcewire field.final - treeRevision → int
-
Value of the
treeRevisionwire field.final - truncated → bool
-
Value of the
truncatedwire field.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this value as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited