isWait property
bool
get
isWait
Whether this request asks the host to wait rather than answer at once.
Implementation
bool get isWait => until != null;
Whether this request asks the host to wait rather than answer at once.
bool get isWait => until != null;