PatchbaySnapshotWaitWire class final

Strict wire representation of PatchbaySnapshotWaitWire.

Constructors

PatchbaySnapshotWaitWire({required String outcome, required PatchbaySnapshotConditionWire condition, required int timeoutMs, required int elapsedMs, required int pollIntervalMs, required int polls})
Creates a fully validated wire value.
const
PatchbaySnapshotWaitWire.fromJson(Map<String, Object?> json, {String path = r'$'})
Decodes a strict JSON object at path.
factory

Properties

condition PatchbaySnapshotConditionWire
Value of the condition wire field.
final
elapsedMs int
Value of the elapsedMs wire field.
final
hashCode int
The hash code for this object.
no setterinherited
outcome String
Value of the outcome wire field.
final
pollIntervalMs int
Value of the pollIntervalMs wire field.
final
polls int
Value of the polls wire field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeoutMs int
Value of the timeoutMs wire field.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this value as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited