PatchbayUiTargetDescriptorWire class final
Strict wire representation of PatchbayUiTargetDescriptorWire.
Constructors
-
PatchbayUiTargetDescriptorWire({required String id, required int generation, required PatchbayUiTargetKindWire kind, required bool mounted, required bool ambiguous, required List<
String> operations, required Map<String, Object?> operationGates, required PatchbaySensitivePolicyWire sensitivePolicy, required PatchbaySideEffectWire sideEffect, required List<PatchbayFactSourceWire> factSources}) -
Creates a fully validated wire value.
const
-
PatchbayUiTargetDescriptorWire.fromJson(Map<
String, Object?> json, {String path = r'$'}) -
Decodes a strict JSON object at
path.factory
Properties
- ambiguous → bool
-
Value of the
ambiguouswire field.final -
factSources
→ List<
PatchbayFactSourceWire> -
Value of the
factSourceswire field.final - generation → int
-
Value of the
generationwire field.final - hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Value of the
idwire field.final - kind → PatchbayUiTargetKindWire
-
Value of the
kindwire field.final - mounted → bool
-
Value of the
mountedwire field.final -
operationGates
→ Map<
String, Object?> -
Value of the
operationGateswire field.final -
operations
→ List<
String> -
Value of the
operationswire field.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sensitivePolicy → PatchbaySensitivePolicyWire
-
Value of the
sensitivePolicywire field.final - sideEffect → PatchbaySideEffectWire
-
Value of the
sideEffectwire field.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this value as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited