PatchbayUiWaitConditionWire enum

Strict wire representation of PatchbayUiWaitConditionWire.

Inheritance
Available extensions

Values

semanticsMounted → const PatchbayUiWaitConditionWire

The semanticsMounted wire value.

semanticsUnmounted → const PatchbayUiWaitConditionWire

The semanticsUnmounted wire value.

semanticsValue → const PatchbayUiWaitConditionWire

The semanticsValue wire value.

The navigationDestination wire value.

treeRevision → const PatchbayUiWaitConditionWire

The treeRevision wire value.

frameRevision → const PatchbayUiWaitConditionWire

The frameRevision wire value.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
Encodes this value using its stable wire name.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Object? value, {String path = r'$'}) PatchbayUiWaitConditionWire
Decodes a value at path, rejecting unknown values.

Constants

values → const List<PatchbayUiWaitConditionWire>
A constant List of the values in this enum, in order of their declaration.