PatchbayUiWaitResultWire class final
Strict wire representation of PatchbayUiWaitResultWire.
Constructors
- PatchbayUiWaitResultWire({required String outcome, required PatchbayFactSourceWire source, required PatchbayUiWaitConditionWire condition, required int elapsedMs, required String? semanticsIdentifier, required int? nodeId, required int? generation, required String? value, required String? destinationId, required int? treeRevision, required int frameRevision})
-
Creates a fully validated wire value.
const
-
PatchbayUiWaitResultWire.fromJson(Map<
String, Object?> json, {String path = r'$'}) -
Decodes a strict JSON object at
path.factory
Properties
- condition → PatchbayUiWaitConditionWire
-
Value of the
conditionwire field.final - destinationId → String?
-
Value of the
destinationIdwire field.final - elapsedMs → int
-
Value of the
elapsedMswire field.final - frameRevision → int
-
Value of the
frameRevisionwire field.final - generation → int?
-
Value of the
generationwire field.final - hashCode → int
-
The hash code for this object.
no setterinherited
-
Value of the
navigationRevisionwire field.final - nodeId → int?
-
Value of the
nodeIdwire field.final - outcome → String
-
Value of the
outcomewire field.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticsIdentifier → String?
-
Value of the
semanticsIdentifierwire field.final - source → PatchbayFactSourceWire
-
Value of the
sourcewire field.final - treeRevision → int?
-
Value of the
treeRevisionwire field.final - value → String?
-
Value of the
valuewire field.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this value as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited