PatchbayResponseValidationIssue class final

One value-free validation issue safe to return to an untrusted caller.

Constructors

PatchbayResponseValidationIssue({required String field, required String reason, String? expected})
const

Properties

expected String?
final
field String
final
hashCode int
The hash code for this object.
no setterinherited
reason String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited