PatchbayCaptureDiffResultWire class final

Strict wire representation of PatchbayCaptureDiffResultWire.

Constructors

PatchbayCaptureDiffResultWire({required String outcome, required PatchbayFactSourceWire source, required String beforeBlobId, required String afterBlobId, required int width, required int height, required String pixelFormat, required int changedPixels, required int totalPixels, required num differenceRatio, required String comparedAt, required int maxPixels, required int maxBytes, required List<PatchbayCaptureWarningWire> warnings})
Creates a fully validated wire value.
const
PatchbayCaptureDiffResultWire.fromJson(Map<String, Object?> json, {String path = r'$'})
Decodes a strict JSON object at path.
factory

Properties

afterBlobId String
Value of the afterBlobId wire field.
final
beforeBlobId String
Value of the beforeBlobId wire field.
final
changedPixels int
Value of the changedPixels wire field.
final
comparedAt String
Value of the comparedAt wire field.
final
differenceRatio num
Value of the differenceRatio wire field.
final
hashCode int
The hash code for this object.
no setterinherited
height int
Value of the height wire field.
final
maxBytes int
Value of the maxBytes wire field.
final
maxPixels int
Value of the maxPixels wire field.
final
outcome String
Value of the outcome wire field.
final
pixelFormat String
Value of the pixelFormat wire field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source PatchbayFactSourceWire
Value of the source wire field.
final
totalPixels int
Value of the totalPixels wire field.
final
warnings List<PatchbayCaptureWarningWire>
Value of the warnings wire field.
final
width int
Value of the width wire field.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this value as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited