PatchbayCaptureResultWire class final

Strict wire representation of PatchbayCaptureResultWire.

Constructors

PatchbayCaptureResultWire({required String outcome, required PatchbayFactSourceWire source, required PatchbayCaptureTargetWire target, required String? targetId, required int? generation, required int width, required int height, required num pixelRatio, required String pixelFormat, required String capturedAt, required int requestedFrames, required int observedFrames, required int maxPixels, required int maxBytes, required List<PatchbayCaptureWarningWire> warnings, required PatchbayBlobMetadataWire blob})
Creates a fully validated wire value.
const
PatchbayCaptureResultWire.fromJson(Map<String, Object?> json, {String path = r'$'})
Decodes a strict JSON object at path.
factory

Properties

blob PatchbayBlobMetadataWire
Value of the blob wire field.
final
capturedAt String
Value of the capturedAt wire field.
final
generation int?
Value of the generation wire field.
final
hashCode int
The hash code for this object.
no setterinherited
height int
Value of the height wire field.
final
maxBytes int
Value of the maxBytes wire field.
final
maxPixels int
Value of the maxPixels wire field.
final
observedFrames int
Value of the observedFrames wire field.
final
outcome String
Value of the outcome wire field.
final
pixelFormat String
Value of the pixelFormat wire field.
final
pixelRatio num
Value of the pixelRatio wire field.
final
requestedFrames int
Value of the requestedFrames wire field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source PatchbayFactSourceWire
Value of the source wire field.
final
target PatchbayCaptureTargetWire
Value of the target wire field.
final
targetId String?
Value of the targetId wire field.
final
warnings List<PatchbayCaptureWarningWire>
Value of the warnings wire field.
final
width int
Value of the width wire field.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this value as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited