PatchbayJobEventWire class final
Strict wire representation of PatchbayJobEventWire.
Constructors
-
PatchbayJobEventWire({required int sequence, required String at, required PatchbayJobPhaseWire phase, required PatchbayFactSourceWire source, required String? operation, required Map<
String, Object?> payload, required String? reason}) -
Creates a fully validated wire value.
const
-
PatchbayJobEventWire.fromJson(Map<
String, Object?> json, {String path = r'$'}) -
Decodes a strict JSON object at
path.factory
Properties
- at → String
-
Value of the
atwire field.final - hashCode → int
-
The hash code for this object.
no setterinherited
- operation → String?
-
Value of the
operationwire field.final -
payload
→ Map<
String, Object?> -
Value of the
payloadwire field.final - phase → PatchbayJobPhaseWire
-
Value of the
phasewire field.final - reason → String?
-
Value of the
reasonwire field.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sequence → int
-
Value of the
sequencewire field.final - source → PatchbayFactSourceWire
-
Value of the
sourcewire field.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this value as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited