PatchbayJobSnapshotWire class final
Strict wire representation of PatchbayJobSnapshotWire.
Constructors
-
PatchbayJobSnapshotWire({required String jobId, required bool terminal, required List<
PatchbayJobEventWire> events}) -
Creates a fully validated wire value.
const
-
PatchbayJobSnapshotWire.fromJson(Map<
String, Object?> json, {String path = r'$'}) -
Decodes a strict JSON object at
path.factory
Properties
-
events
→ List<
PatchbayJobEventWire> -
Value of the
eventswire field.final - hashCode → int
-
The hash code for this object.
no setterinherited
- jobId → String
-
Value of the
jobIdwire field.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terminal → bool
-
Value of the
terminalwire field.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this value as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited