PatchbayKeepAwakeStateWire class final

Strict wire representation of PatchbayKeepAwakeStateWire.

Constructors

PatchbayKeepAwakeStateWire({required String outcome, required PatchbayFactSourceWire source, required bool wired, required bool enabled, required int? leaseMs, required int? leaseRemainingMs, required PatchbayKeepAwakeReleaseWire? lastRelease, required String? lastReleaseFailure})
Creates a fully validated wire value.
const
PatchbayKeepAwakeStateWire.fromJson(Map<String, Object?> json, {String path = r'$'})
Decodes a strict JSON object at path.
factory

Properties

enabled bool
Value of the enabled wire field.
final
hashCode int
The hash code for this object.
no setterinherited
lastRelease PatchbayKeepAwakeReleaseWire?
Value of the lastRelease wire field.
final
lastReleaseFailure String?
Value of the lastReleaseFailure wire field.
final
leaseMs int?
Value of the leaseMs wire field.
final
leaseRemainingMs int?
Value of the leaseRemainingMs wire field.
final
outcome String
Value of the outcome wire field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source PatchbayFactSourceWire
Value of the source wire field.
final
wired bool
Value of the wired wire field.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this value as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited