PatchbayLogBatchWire class final
Strict wire representation of PatchbayLogBatchWire.
Constructors
-
PatchbayLogBatchWire({required PatchbayLogBatchOutcomeWire outcome, required PatchbayFactSourceWire source, required List<
PatchbayLogRecordWire> records, required String? nextCursor, required String? currentCursor, required bool truncated, required PatchbayLogTruncationWire? truncation, required int elapsedMs}) -
Creates a fully validated wire value.
const
-
PatchbayLogBatchWire.fromJson(Map<
String, Object?> json, {String path = r'$'}) -
Decodes a strict JSON object at
path.factory
Properties
- currentCursor → String?
-
Value of the
currentCursorwire field.final - elapsedMs → int
-
Value of the
elapsedMswire field.final - hashCode → int
-
The hash code for this object.
no setterinherited
- nextCursor → String?
-
Value of the
nextCursorwire field.final - outcome → PatchbayLogBatchOutcomeWire
-
Value of the
outcomewire field.final -
records
→ List<
PatchbayLogRecordWire> -
Value of the
recordswire field.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → PatchbayFactSourceWire
-
Value of the
sourcewire field.final - truncated → bool
-
Value of the
truncatedwire field.final - truncation → PatchbayLogTruncationWire?
-
Value of the
truncationwire field.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this value as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited