PatchbayLogExportRequestWire class final
Strict wire representation of PatchbayLogExportRequestWire.
Constructors
-
PatchbayLogExportRequestWire({required String? cursor, required PatchbayLogDirectionWire? direction, required int? limit, required List<
PatchbayLogLevelWire> levels, required List<String> categories, required String? since, required String? until, required int? ttlMs}) -
Creates a fully validated wire value.
const
-
PatchbayLogExportRequestWire.fromJson(Map<
String, Object?> json, {String path = r'$'}) -
Decodes a strict JSON object at
path.factory
Properties
-
categories
→ List<
String> -
Value of the
categorieswire field.final - cursor → String?
-
Value of the
cursorwire field.final - direction → PatchbayLogDirectionWire?
-
Value of the
directionwire field.final - hashCode → int
-
The hash code for this object.
no setterinherited
-
levels
→ List<
PatchbayLogLevelWire> -
Value of the
levelswire field.final - limit → int?
-
Value of the
limitwire field.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- since → String?
-
Value of the
sincewire field.final - ttlMs → int?
-
Value of the
ttlMswire field.final - until → String?
-
Value of the
untilwire field.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this value as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited