PatchbayLogTailRequestWire class final
Strict wire representation of PatchbayLogTailRequestWire.
Constructors
-
PatchbayLogTailRequestWire({required String? cursor, required int? limit, required int? timeoutMs, required List<
PatchbayLogLevelWire> levels, required List<String> categories}) -
Creates a fully validated wire value.
const
-
PatchbayLogTailRequestWire.fromJson(Map<
String, Object?> json, {String path = r'$'}) -
Decodes a strict JSON object at
path.factory
Properties
-
categories
→ List<
String> -
Value of the
categorieswire field.final - cursor → String?
-
Value of the
cursorwire field.final - hashCode → int
-
The hash code for this object.
no setterinherited
-
levels
→ List<
PatchbayLogLevelWire> -
Value of the
levelswire field.final - limit → int?
-
Value of the
limitwire field.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeoutMs → int?
-
Value of the
timeoutMswire field.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this value as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited