PatchbayNavigationResultWire class final

Strict wire representation of PatchbayNavigationResultWire.

Constructors

PatchbayNavigationResultWire({required String outcome, required PatchbayFactSourceWire source, required PatchbayNavigationOperationWire operation, required String? requestedDestinationId, required String destinationId, required int beforeNavigationRevision, required int afterNavigationRevision, required int frameRevision})
Creates a fully validated wire value.
const
PatchbayNavigationResultWire.fromJson(Map<String, Object?> json, {String path = r'$'})
Decodes a strict JSON object at path.
factory

Properties

afterNavigationRevision int
Value of the afterNavigationRevision wire field.
final
beforeNavigationRevision int
Value of the beforeNavigationRevision wire field.
final
destinationId String
Value of the destinationId wire field.
final
frameRevision int
Value of the frameRevision wire field.
final
hashCode int
The hash code for this object.
no setterinherited
operation PatchbayNavigationOperationWire
Value of the operation wire field.
final
outcome String
Value of the outcome wire field.
final
requestedDestinationId String?
Value of the requestedDestinationId wire field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source PatchbayFactSourceWire
Value of the source wire field.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this value as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited