PatchbayParameterDescriptorWire class final
Strict wire representation of PatchbayParameterDescriptorWire.
Constructors
-
PatchbayParameterDescriptorWire({required String name, required PatchbayParameterTypeWire type, required bool required, required bool sensitive, required Object? defaultValue, required List<
Object?> allowedValues, required String? summary}) -
Creates a fully validated wire value.
const
-
PatchbayParameterDescriptorWire.fromJson(Map<
String, Object?> json, {String path = r'$'}) -
Decodes a strict JSON object at
path.factory
Properties
-
allowedValues
→ List<
Object?> -
Value of the
allowedValueswire field.final - defaultValue → Object?
-
Value of the
defaultwire field.final - hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Value of the
namewire field.final - required → bool
-
Value of the
requiredwire field.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sensitive → bool
-
Value of the
sensitivewire field.final - summary → String?
-
Value of the
summarywire field.final - type → PatchbayParameterTypeWire
-
Value of the
typewire field.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this value as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited