PatchbayPermissionCapability class final
Constructors
-
PatchbayPermissionCapability({required Set<
PatchbayPermissionAction> actions, Set<PatchbayPermissionDecision> decisions = const <PatchbayPermissionDecision>{}}) -
const
-
PatchbayPermissionCapability.fromJson(Map<
String, Object?> json) -
factory
Properties
-
actions
→ Set<
PatchbayPermissionAction> -
final
-
decisions
→ Set<
PatchbayPermissionDecision> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited