PatchbayPermissionDriverRequest class final

Constructors

PatchbayPermissionDriverRequest({String protocolVersion = patchbayPermissionProtocolVersion, required String requestId, required PatchbayPermissionOperation operation, String? deviceId, String? applicationId, Map<String, Object?>? sessionRef, String? permission, String? policy, PatchbayPermissionState? state, PatchbayPermissionDecision? decision, required int timeoutMs})
const
PatchbayPermissionDriverRequest.fromJson(Map<String, Object?> json)
factory

Properties

applicationId String?
final
decision PatchbayPermissionDecision?
final
deviceId String?
final
hashCode int
The hash code for this object.
no setterinherited
operation PatchbayPermissionOperation
final
permission String?
final
policy String?
final
protocolVersion String
final
requestId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionRef Map<String, Object?>?
final
state PatchbayPermissionState?
final
timeoutMs int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited