PatchbayPermissionDriverResponse class final
Constructors
-
PatchbayPermissionDriverResponse({required String protocolVersion, required String requestId, required String admission, String? code, Map<
String, Object?> details = const <String, Object?>{}, PatchbayPermissionCapabilities? capabilities, PatchbayPermissionStatus? before, PatchbayPermissionStatus? after, List<PatchbayPermissionEvidence> evidence = const <PatchbayPermissionEvidence>[], PatchbayPermissionInterruption? interruption, String? notice}) -
const
-
PatchbayPermissionDriverResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- accepted → bool
-
no setter
- admission → String
-
final
- after → PatchbayPermissionStatus?
-
final
- before → PatchbayPermissionStatus?
-
final
- capabilities → PatchbayPermissionCapabilities?
-
final
- code → String?
-
final
-
details
→ Map<
String, Object?> -
final
-
evidence
→ List<
PatchbayPermissionEvidence> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- interruption → PatchbayPermissionInterruption?
-
final
- notice → String?
-
final
- protocolVersion → String
-
final
- requestId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited