PatchbayPermissionInterruption class final
Constructors
- PatchbayPermissionInterruption({required bool expected, required bool handled, String? permission, PatchbayPermissionDecision? decision, String? code})
-
const
-
PatchbayPermissionInterruption.fromJson(Map<
String, Object?> json) -
factory
Properties
- code → String?
-
final
- decision → PatchbayPermissionDecision?
-
final
- expected → bool
-
final
- handled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- permission → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited