PatchbayRejectionWire class final

Strict wire representation of PatchbayRejectionWire.

Constructors

PatchbayRejectionWire({required String code, required String? notice, required Map<String, Object?> details})
Creates a fully validated wire value.
const
PatchbayRejectionWire.fromJson(Map<String, Object?> json, {String path = r'$'})
Decodes a strict JSON object at path.
factory

Properties

code String
Value of the code wire field.
final
details Map<String, Object?>
Value of the details wire field.
final
hashCode int
The hash code for this object.
no setterinherited
notice String?
Value of the notice wire field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this value as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited