PatchbayRevealRequestWire class final
Strict wire representation of PatchbayRevealRequestWire.
Constructors
- PatchbayRevealRequestWire({required String identifier, required String? container, required PatchbayRevealDirectionWire? direction, required int? maxSteps, required int? timeoutMs})
-
Creates a fully validated wire value.
const
-
PatchbayRevealRequestWire.fromJson(Map<
String, Object?> json, {String path = r'$'}) -
Decodes a strict JSON object at
path.factory
Properties
- container → String?
-
Value of the
containerwire field.final - direction → PatchbayRevealDirectionWire?
-
Value of the
directionwire field.final - hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String
-
Value of the
identifierwire field.final - maxSteps → int?
-
Value of the
maxStepswire field.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeoutMs → int?
-
Value of the
timeoutMswire field.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this value as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited