PatchbayRevealResultWire class final

Strict wire representation of PatchbayRevealResultWire.

Constructors

PatchbayRevealResultWire({required String outcome, required PatchbayFactSourceWire source, required String identifier, required int steps, required int elapsedMs, required List<PatchbayRevealContainerWire> containers, required int? nodeId, required int? generation, required PatchbayRevealReachabilityWire? reachability, required int beforeTreeRevision, required int afterTreeRevision, required String? reason, required String? failureType, required String? gateId, required String? gateCode})
Creates a fully validated wire value.
const
PatchbayRevealResultWire.fromJson(Map<String, Object?> json, {String path = r'$'})
Decodes a strict JSON object at path.
factory

Properties

afterTreeRevision int
Value of the afterTreeRevision wire field.
final
beforeTreeRevision int
Value of the beforeTreeRevision wire field.
final
containers List<PatchbayRevealContainerWire>
Value of the containers wire field.
final
elapsedMs int
Value of the elapsedMs wire field.
final
failureType String?
Value of the failureType wire field.
final
gateCode String?
Value of the gateCode wire field.
final
gateId String?
Value of the gateId wire field.
final
generation int?
Value of the generation wire field.
final
hashCode int
The hash code for this object.
no setterinherited
identifier String
Value of the identifier wire field.
final
nodeId int?
Value of the nodeId wire field.
final
outcome String
Value of the outcome wire field.
final
reachability PatchbayRevealReachabilityWire?
Value of the reachability wire field.
final
reason String?
Value of the reason wire field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source PatchbayFactSourceWire
Value of the source wire field.
final
steps int
Value of the steps wire field.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this value as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited