PatchbaySemanticsNodeWire class final
Strict wire representation of PatchbaySemanticsNodeWire.
Constructors
-
PatchbaySemanticsNodeWire({required int nodeId, required int generation, required int? parentNodeId, required int depth, required String identifier, required String label, required String? value, required bool? valueRedacted, required String? hint, required String? tooltip, required List<
String> flags, required List<String> actions, required bool invisible, required bool userActionsBlocked, required PatchbaySemanticsRectWire rect, required String rectCoordinateSpace, required List<num> ? transformToParent, required num? scrollPosition, required num? scrollExtentMin, required num? scrollExtentMax, required int? platformViewId, required List<int> children}) -
Creates a fully validated wire value.
const
-
PatchbaySemanticsNodeWire.fromJson(Map<
String, Object?> json, {String path = r'$'}) -
Decodes a strict JSON object at
path.factory
Properties
-
actions
→ List<
String> -
Value of the
actionswire field.final -
children
→ List<
int> -
Value of the
childrenwire field.final - depth → int
-
Value of the
depthwire field.final -
flags
→ List<
String> -
Value of the
flagswire field.final - generation → int
-
Value of the
generationwire field.final - hashCode → int
-
The hash code for this object.
no setterinherited
- hint → String?
-
Value of the
hintwire field.final - identifier → String
-
Value of the
identifierwire field.final - invisible → bool
-
Value of the
invisiblewire field.final - label → String
-
Value of the
labelwire field.final - nodeId → int
-
Value of the
nodeIdwire field.final - parentNodeId → int?
-
Value of the
parentNodeIdwire field.final - platformViewId → int?
-
Value of the
platformViewIdwire field.final - rect → PatchbaySemanticsRectWire
-
Value of the
rectwire field.final - rectCoordinateSpace → String
-
Value of the
rectCoordinateSpacewire field.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollExtentMax → num?
-
Value of the
scrollExtentMaxwire field.final - scrollExtentMin → num?
-
Value of the
scrollExtentMinwire field.final - scrollPosition → num?
-
Value of the
scrollPositionwire field.final - tooltip → String?
-
Value of the
tooltipwire field.final -
transformToParent
→ List<
num> ? -
Value of the
transformToParentwire field.final - userActionsBlocked → bool
-
Value of the
userActionsBlockedwire field.final - value → String?
-
Value of the
valuewire field.final - valueRedacted → bool?
-
Value of the
valueRedactedwire field.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this value as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited