PatchbaySemanticsSnapshotWire class final

Strict wire representation of PatchbaySemanticsSnapshotWire.

Constructors

PatchbaySemanticsSnapshotWire({required String outcome, required PatchbayFactSourceWire source, required int treeRevision, required int rootNodeId, required bool truncated, required int nodeCount, required List<PatchbaySemanticsNodeWire> nodes})
Creates a fully validated wire value.
const
PatchbaySemanticsSnapshotWire.fromJson(Map<String, Object?> json, {String path = r'$'})
Decodes a strict JSON object at path.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
nodeCount int
Value of the nodeCount wire field.
final
nodes List<PatchbaySemanticsNodeWire>
Value of the nodes wire field.
final
outcome String
Value of the outcome wire field.
final
rootNodeId int
Value of the rootNodeId wire field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source PatchbayFactSourceWire
Value of the source wire field.
final
treeRevision int
Value of the treeRevision wire field.
final
truncated bool
Value of the truncated wire field.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this value as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited