PatchbaySnapshotRequestWire class final
Strict wire representation of PatchbaySnapshotRequestWire.
Constructors
- PatchbaySnapshotRequestWire({required String path, required PatchbaySnapshotConditionWire? until, required Object? value, required int? timeoutMs})
-
Creates a fully validated wire value.
const
-
PatchbaySnapshotRequestWire.fromJson(Map<
String, Object?> json, {String path = r'$'}) -
Decodes a strict JSON object at
path.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- path → String
-
Value of the
pathwire field.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeoutMs → int?
-
Value of the
timeoutMswire field.final - until → PatchbaySnapshotConditionWire?
-
Value of the
untilwire field.final - value → Object?
-
Value of the
valuewire field.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this value as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited