PatchbaySnapshotSelection class final
One resolution of a PatchbaySnapshotRequest.path against a snapshot.
Constructors
- PatchbaySnapshotSelection.found(String path, Object? value)
-
const
- PatchbaySnapshotSelection.missing(String path, PatchbaySnapshotMiss miss)
-
const
-
PatchbaySnapshotSelection.resolve(Map<
String, Object?> snapshot, String path) -
Resolves
pathagainstsnapshot, segment by segment.factory
Properties
- found → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- miss → PatchbaySnapshotMiss?
-
Why the path resolved to nothing, or null when it resolved.
final
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → Object?
-
The resolved value, or null when this is a miss.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
satisfies(
PatchbaySnapshotCondition condition, Object? expected) → bool -
Whether
conditionholds for this resolution. -
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
-
toWire(
) → PatchbaySnapshotSelectionWire
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited