PatchbaySnapshotSelectionWire class final
Strict wire representation of PatchbaySnapshotSelectionWire.
Constructors
- PatchbaySnapshotSelectionWire({required String path, required bool found, required Object? value, required PatchbaySnapshotMissWire? miss})
-
Creates a fully validated wire value.
const
-
PatchbaySnapshotSelectionWire.fromJson(Map<
String, Object?> json, {String path = r'$'}) -
Decodes a strict JSON object at
path.factory
Properties
- found → bool
-
Value of the
foundwire field.final - hashCode → int
-
The hash code for this object.
no setterinherited
- miss → PatchbaySnapshotMissWire?
-
Value of the
misswire field.final - path → String
-
Value of the
pathwire field.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → Object?
-
Value of the
valuewire field.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this value as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited