PatchbaySnapshotWaitWire class final
Strict wire representation of PatchbaySnapshotWaitWire.
Constructors
- PatchbaySnapshotWaitWire({required String outcome, required PatchbaySnapshotConditionWire condition, required int timeoutMs, required int elapsedMs, required int pollIntervalMs, required int polls})
-
Creates a fully validated wire value.
const
-
PatchbaySnapshotWaitWire.fromJson(Map<
String, Object?> json, {String path = r'$'}) -
Decodes a strict JSON object at
path.factory
Properties
- condition → PatchbaySnapshotConditionWire
-
Value of the
conditionwire field.final - elapsedMs → int
-
Value of the
elapsedMswire field.final - hashCode → int
-
The hash code for this object.
no setterinherited
- outcome → String
-
Value of the
outcomewire field.final - pollIntervalMs → int
-
Value of the
pollIntervalMswire field.final - polls → int
-
Value of the
pollswire field.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeoutMs → int
-
Value of the
timeoutMswire field.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this value as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited