patchbayUiGestureTapCommandDescriptor top-level property
tap 是家族里唯一没有 durationMs 的成员:down→up 间隔是实现内部常数,
不进 wire(DG-050-08 复核改判)。它的 start 也因此从"路径起点"退化为
"唯一那个点",可缺省到目标中心——默认值必须进 descriptor 而不是只写在
实现里,catalog 是调用方唯一读得到的声明面。两处形状开关都带默认值,
既有三条 descriptor 的字节因此一位不变。
Implementation
final patchbayUiGestureTapCommandDescriptor = _gesture(
'ui.gesture.tap',
'Tap inside a Semantics identifier target through the real pointer '
'pipeline.',
'uiGestureTap',
'tap',
'Tap an anchored target through the real pointer pipeline.',
extraParameters: const <PatchbayParameterDescriptor>[],
extraOptions: const <String, String>{},
usageSuffix: '<identifier> <generation> [--start <json>]',
startRequired: false,
startDefault: const <String, Object?>{'x': 0.5, 'y': 0.5},
positiveParameters: const <String>{},
);