patchbayUiInspectSelectCommandDescriptor top-level property
Implementation
final patchbayUiInspectSelectCommandDescriptor = _ui(
'ui.inspect.select',
'Turn the widget inspector select mode on or off, under a lease.',
facts: _appFacts,
parameters: <PatchbayParameterDescriptor>[
const PatchbayParameterDescriptor(
name: 'enabled',
type: PatchbayParameterType.boolean,
required: true,
summary: 'Whether taps on the device select widgets.',
),
const PatchbayParameterDescriptor(
name: 'ttlMs',
type: PatchbayParameterType.integer,
defaultValue: 300000,
summary:
'Lease for an enable; the App restores the switch when it expires '
'without a renewal. Only valid with enabled=true.',
),
],
cliSyntax: const <PatchbayCliSyntax>[
PatchbayCliSyntax(
id: 'uiInspectOn',
path: <String>['ui', 'inspect', 'on'],
summary:
'Turn widget select mode on for a lease, then it restores itself.',
usageSuffix: '[--ttl-ms <ms>]',
optionParameters: <String, String>{'ttlMs': 'ttl-ms'},
positiveParameters: <String>{'ttlMs'},
omitOptionDefaults: <String>{'ttlMs'},
fixedArguments: <String, Object?>{'enabled': true},
),
PatchbayCliSyntax(
id: 'uiInspectOff',
path: <String>['ui', 'inspect', 'off'],
summary: 'Turn widget select mode off and release the lease.',
fixedArguments: <String, Object?>{'enabled': false},
),
],
);