patchbayUiSemanticsTapCommandDescriptor top-level property
Implementation
final patchbayUiSemanticsTapCommandDescriptor = _ui(
'ui.semantics.tap',
'Resolve a stable Semantics identifier and tap it in one request.',
interactionModel: PatchbayInteractionModel.userLike,
parameters: <PatchbayParameterDescriptor>[
_p('identifier', PatchbayParameterType.string, required: true),
_p('generation', PatchbayParameterType.integer),
],
cliSyntax: const <PatchbayCliSyntax>[
PatchbayCliSyntax(
id: 'uiTap',
path: <String>['ui', 'tap'],
summary: 'Resolve a semantics identifier and tap it in one request.',
usageSuffix: '<identifier> [--generation <generation>]',
positionalParameters: <String>['identifier'],
optionParameters: <String, String>{'generation': 'generation'},
nonNegativeParameters: <String>{'generation'},
),
],
);